==> org.eclipse.scout.sdk.s2e.ui.source_11.0.24.jar: org/eclipse/scout/sdk/s2e/ui/internal/nls/TranslationModifyDialog.java <==
/*
 * Copyright (c) 2010-2020 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 */
package org.eclipse.scout.sdk.s2e.ui.internal.nls;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.window.Window;
import org.eclipse.scout.sdk.core.s.nls.ITranslationEntry;
import org.eclipse.scout.sdk.core.s.nls.Language;
import org.eclipse.scout.sdk.core.s.nls.TranslationStoreStack;
import org.eclipse.scout.sdk.s2e.ui.wizard.AbstractWizardPage;
import org.eclipse.swt.widgets.Shell;

/**
 * <h4>NlsEntryModifyDialog</h4>
 */
public class TranslationModifyDialog extends AbstractTranslationDialog {

  public TranslationModifyDialog(Shell parentShell, TranslationStoreStack project, ITranslationEntry row) {
    super(parentShell, "Modify Entry", row, project, false);
    setSelectedStore(row.store());
  }

  @Override
  protected void postCreate() {
    getKeyField().setEnabled(false);

    var defaultField = getDefaultTranslationField();
    if (defaultField != null) {
      defaultField.addModifyListener(e -> revalidate());
    }

    revalidate();
  }

  @Override
  protected void revalidate() {
    var defaultLangField = getTranslationField(Language.LANGUAGE_DEFAULT);
    if (defaultLangField == null) {
      return;
    }

    var status = TranslationInputValidator.validateDefaultTranslation(defaultLangField.getText());
    if (status.isOK()) {
      setMessage("Create a new translation entry.");
    }
    else {
      setMessage(AbstractWizardPage.getHighestSeverityStatus(status));
    }
    getButton(Window.OK).setEnabled(status.getSeverity() != IStatus.ERROR);
  }
}

==> org.eclipse.scout.sdk.s2e.ui.source_11.0.39.jar: org/eclipse/scout/sdk/s2e/ui/internal/nls/TranslationModifyDialog.java <==
/*
 * Copyright (c) 2010-2021 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 */
package org.eclipse.scout.sdk.s2e.ui.internal.nls;

import java.util.stream.Collectors;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.jface.window.Window;
import org.eclipse.scout.sdk.core.s.nls.Language;
import org.eclipse.scout.sdk.core.s.nls.manager.IStackedTranslation;
import org.eclipse.scout.sdk.core.s.nls.manager.TranslationManager;
import org.eclipse.scout.sdk.s2e.ui.wizard.AbstractWizardPage;
import org.eclipse.swt.widgets.Shell;

/**
 * <h4>NlsEntryModifyDialog</h4>
 */
public class TranslationModifyDialog extends AbstractTranslationDialog {

  public TranslationModifyDialog(Shell parentShell, TranslationManager project, IStackedTranslation translation) {
    super(parentShell, "Modify Entry", translation, project, translation.languagesOfAllStores().collect(Collectors.toList()), false);
  }

  @Override
  protected void postCreate() {
    getKeyField().setEnabled(false);

    var defaultField = getDefaultTranslationField();
    if (defaultField != null) {
      defaultField.addModifyListener(e -> revalidate());
    }

    revalidate();
  }

  @Override
  protected void revalidate() {
    var defaultLangField = getTranslationField(Language.LANGUAGE_DEFAULT);
    if (defaultLangField == null) {
      return;
    }

    var status = TranslationInputValidator.validateDefaultTranslation(defaultLangField.getText());
    if (status.isOK()) {
      setMessage("Create a new translation entry.");
    }
    else {
      setMessage(AbstractWizardPage.getHighestSeverityStatus(status));
    }
    getButton(Window.OK).setEnabled(status.getSeverity() != IStatus.ERROR);
  }
}
